/**
 * Calculates the estimated time it takes to read a piece of text.
 * @param {string} text - The text to be read.
 * @param {number} [imageCounter=0] - The number of images in the text.
 * @returns {string} - The estimated time it takes to read the text, in the format "Xm" where X is the number of minutes.
 */
export declare const s_readTime: (text: string, imageCounter?: number) => string;
/**
 * Calculates the estimated time it takes to read text based on the number of words and a given words per minute rate.
 * @param {string} text - The text to be read.
 * @param {number} [wordsPerMin=WORDS_PER_MIN] - The words per minute rate to use for calculating read time.
 * @returns {number} - The estimated time it takes to read the text in minutes.
 */
export declare const calculateWordsReadTime: (text: string, wordsPerMin?: number) => number;
/**
 * Removes any Chinese, Japanese, or Korean characters from a string.
 * @param {string} text - The text to be processed.
 * @returns {string} - The text with all CJK characters removed.
 */
export declare const removeOtherLanguageCharacters: (text: string) => string;
/**
 * Calculates the estimated time it takes to read images based on the number of images and a given time per image.
 * @param {number} count - The number of images to be read.
 * @param {number} [customImageTime=IMAGE_READ_TIME] - The time per image to use for calculating read time.
 * @returns {number} - The estimated time it takes to read the images in minutes.
 */
export declare const imageReadTime: (count: number, customImageTime?: number) => number;
//# sourceMappingURL=read-time.d.ts.map